import 'dart:developer' as developer;

import 'package:path/path.dart' as path;
import 'package:stack_trace/stack_trace.dart';

/// Example :
///
///[Log model]__________________________________________________________________
///  Test model = Test(value_1: "value_1", value_2: "value_2");
///  model.Log("get Content model :..")
///
///  Result => get Content model :.. {"value_1":"value_1","value_2":"value_2"}
///_____________________________________________________________________________
///
///
/// test comment.
/// extension any with logcat.
extension TypeExtension<T> on T {
  // ignore: non_constant_identifier_names
  T Log(
      [String tag = "",
      bool isLargeString = false,
      String tagName = "logger:~~~/"]) {
    Frame trace = Trace.current(1).terse.frames[0];
    var library = path.prettyUri(trace.uri);
    var line = trace.line;
    var column = trace.column;
    var url = '$library $line:$column ⇙';

    /// check type object...
    String content = toString();

    if (isLargeString) {
      developer.log(
        "$content\n"
        "========================================================================================================================================================",
        name: tag.isEmpty ? "large string" : "$tagName $url",
      );
      return this;
    }

    if (tag.isNotEmpty) {
      print("$tagName $url\n⋙ $tag $content");
    } else {
      print("$tagName $url\n⋙ $content");
    }

    return this;
  }
}
